==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/InMageAzureV2DiskInputDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.InMageAzureV2DiskInputDetailsArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.DiskAccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Disk input details.
 * @property diskEncryptionSetId The DiskEncryptionSet ARM ID.
 * @property diskId The DiskId.
 * @property diskType The DiskType.
 * @property logStorageAccountId The LogStorageAccountId.
 */
public data class InMageAzureV2DiskInputDetailsArgs(
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskId: Output<String>? = null,
    public val diskType: Output<Either<String, DiskAccountType>>? = null,
    public val logStorageAccountId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.InMageAzureV2DiskInputDetailsArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.InMageAzureV2DiskInputDetailsArgs =
        com.pulumi.azurenative.recoveryservices.inputs.InMageAzureV2DiskInputDetailsArgs.builder()
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskId(diskId?.applyValue({ args0 -> args0 }))
            .diskType(
                diskType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .logStorageAccountId(logStorageAccountId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InMageAzureV2DiskInputDetailsArgs].
 */
@PulumiTagMarker
public class InMageAzureV2DiskInputDetailsArgsBuilder internal constructor() {
    private var diskEncryptionSetId: Output<String>? = null

    private var diskId: Output<String>? = null

    private var diskType: Output<Either<String, DiskAccountType>>? = null

    private var logStorageAccountId: Output<String>? = null

    /**
     * @param value The DiskEncryptionSet ARM ID.
     */
    @JvmName("kdpxktmkpxnvbqcv")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The DiskId.
     */
    @JvmName("nctsnikhouwmcxqh")
    public suspend fun diskId(`value`: Output<String>) {
        this.diskId = value
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("jsupbeagiysfqjdx")
    public suspend fun diskType(`value`: Output<Either<String, DiskAccountType>>) {
        this.diskType = value
    }

    /**
     * @param value The LogStorageAccountId.
     */
    @JvmName("dawolkpvtswajoob")
    public suspend fun logStorageAccountId(`value`: Output<String>) {
        this.logStorageAccountId = value
    }

    /**
     * @param value The DiskEncryptionSet ARM ID.
     */
    @JvmName("wkidivbmviuqiqbf")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The DiskId.
     */
    @JvmName("vsdsntnhexmamhyj")
    public suspend fun diskId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskId = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("ngpcrlltqxnqpfon")
    public suspend fun diskType(`value`: Either<String, DiskAccountType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("wfswusacgaqlrdag")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("tdntoowiyaijdmfn")
    public fun diskType(`value`: DiskAccountType) {
        val toBeMapped = Either.ofRight<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The LogStorageAccountId.
     */
    @JvmName("bpbcfnrgkqpmidvy")
    public suspend fun logStorageAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logStorageAccountId = mapped
    }

    internal fun build(): InMageAzureV2DiskInputDetailsArgs = InMageAzureV2DiskInputDetailsArgs(
        diskEncryptionSetId = diskEncryptionSetId,
        diskId = diskId,
        diskType = diskType,
        logStorageAccountId = logStorageAccountId,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/InMageAzureV2DiskInputDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.InMageAzureV2DiskInputDetailsArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.DiskAccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Disk input details.
 * @property diskEncryptionSetId The DiskEncryptionSet ARM ID.
 * @property diskId The DiskId.
 * @property diskType The DiskType.
 * @property logStorageAccountId The LogStorageAccountId.
 */
public data class InMageAzureV2DiskInputDetailsArgs(
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskId: Output<String>? = null,
    public val diskType: Output<Either<String, DiskAccountType>>? = null,
    public val logStorageAccountId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.InMageAzureV2DiskInputDetailsArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.InMageAzureV2DiskInputDetailsArgs =
        com.pulumi.azurenative.recoveryservices.inputs.InMageAzureV2DiskInputDetailsArgs.builder()
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskId(diskId?.applyValue({ args0 -> args0 }))
            .diskType(
                diskType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .logStorageAccountId(logStorageAccountId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InMageAzureV2DiskInputDetailsArgs].
 */
@PulumiTagMarker
public class InMageAzureV2DiskInputDetailsArgsBuilder internal constructor() {
    private var diskEncryptionSetId: Output<String>? = null

    private var diskId: Output<String>? = null

    private var diskType: Output<Either<String, DiskAccountType>>? = null

    private var logStorageAccountId: Output<String>? = null

    /**
     * @param value The DiskEncryptionSet ARM ID.
     */
    @JvmName("xocaqahldlmqeoin")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The DiskId.
     */
    @JvmName("ctgwudscyfmvfwvt")
    public suspend fun diskId(`value`: Output<String>) {
        this.diskId = value
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("slngpgrjpinuekvc")
    public suspend fun diskType(`value`: Output<Either<String, DiskAccountType>>) {
        this.diskType = value
    }

    /**
     * @param value The LogStorageAccountId.
     */
    @JvmName("sfufvljovmrsqsvk")
    public suspend fun logStorageAccountId(`value`: Output<String>) {
        this.logStorageAccountId = value
    }

    /**
     * @param value The DiskEncryptionSet ARM ID.
     */
    @JvmName("kyxkgihkcnwwayft")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The DiskId.
     */
    @JvmName("axdccefvydmkudbw")
    public suspend fun diskId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskId = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("swrjuqxajikjvymw")
    public suspend fun diskType(`value`: Either<String, DiskAccountType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("khejwfkxyyogkkjw")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("wqyboplfbpgsqlhg")
    public fun diskType(`value`: DiskAccountType) {
        val toBeMapped = Either.ofRight<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The LogStorageAccountId.
     */
    @JvmName("dlqwjfbtibgkoglu")
    public suspend fun logStorageAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logStorageAccountId = mapped
    }

    internal fun build(): InMageAzureV2DiskInputDetailsArgs = InMageAzureV2DiskInputDetailsArgs(
        diskEncryptionSetId = diskEncryptionSetId,
        diskId = diskId,
        diskType = diskType,
        logStorageAccountId = logStorageAccountId,
    )
}
